using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Text;
using System.Web.UI;
using System.Web.UI.WebControls.WebParts;
using Microsoft.SharePoint.Utilities;
using Microsoft.SharePoint.WebPartPages;

namespace FilterWPDemo {

    public class StockQuotes : Microsoft.SharePoint.WebPartPages.WebPart
    {
        IFilterValues valuesProvider;
        private FilterConsumerInfoBar infoBar;
        private LiteralControl quoteTable;

        [ConnectionConsumer("Stock Symbols")]
        public void SetConnectionInterface(IFilterValues provider)
        {
            valuesProvider = provider;
            List<ConsumerParameter> l = new List<ConsumerParameter>();
            l.Add(new ConsumerParameter("Stock Symbols", ConsumerParameterCapabilities.SupportsMultipleValues));
            provider.SetConsumerParameters(new ReadOnlyCollection<ConsumerParameter>(l));
        }

        protected override void CreateChildControls()
        {
            infoBar = new FilterConsumerInfoBar();
            Controls.Add(infoBar);

            quoteTable = new LiteralControl();
            Controls.Add(quoteTable);

            base.CreateChildControls();
        }

        protected override void OnPreRender(EventArgs e)
        {
            EnsureChildControls();
            if (valuesProvider != null)
            {
                ReadOnlyCollection<String> values = valuesProvider.ParameterValues;
                if (values != null)
                {
                    StringBuilder sb = new StringBuilder();
                    sb.AppendLine("<TABLE><TR><TD><B>Symbol</B></TD><TD><B>Price</B></TD></TR>");
                    foreach (string value in values)
                    {
                        if (value != null)
                        {
                            sb.Append("<TR><TD>" + SPEncode.HtmlEncode(value) + "</TD>");
                            double price = GetPrice(value);
                            sb.AppendLine("<TD>" + price.ToString("0.00") + "</TD></TR>");
                        }
                    }
                    sb.AppendLine("</TABLE>");
                    quoteTable.Text = sb.ToString();
                }
                else  // no values received
                {
                    quoteTable.Text = "No stock symbols provided.";
                }
            }
            else  // no valuesProvider
            {
                quoteTable.Text = "Use web part connections to supply the list of stock symbols.";
            }
            base.OnPreRender(e);
        }

        private double GetPrice(string symbol)
        {
            Random rand = new Random();

            switch (symbol)
            {
                case "MSFT":
                    return 26.5 + (rand.NextDouble() * 2) - 1;
                case "GE":
                    return 34 + (rand.NextDouble() * 2.5) - 1;
                case "WMT":
                    return 45 + (rand.NextDouble() * 3) - 1.5;
                default:
                    return 35 + (rand.NextDouble() * 5) - 2.5;
            }
        }
    }
}
